//-------+---------+---------+---------+---------+---------+---------+-----
// wingcd.c - Multi-Media Wingman Ver01.01 Eternal 
//          - Wingman Linear PCM Wave Player
//-------+---------+---------+---------+---------+---------+---------+-----

///////////////////////////////////////////////////////////////////////////
// Copyright (C) GENERAL SCIENCE (M.Kasahara) since 1999.01
// Programmed by GENERAL SCIENCE (M.Kasahara)
// Ver00.30 2000.09 - Wingman Ver01.01
///////////////////////////////////////////////////////////////////////////
// !!! Information !!! - Find ">>>" for find function in this source.
///////////////////////////////////////////////////////////////////////////

#include <stdio.h>
#include <WGM/mwingman.h>

#include "resource.h"

#define TRUE  1
#define FALSE 0
#define FILES 100

static char g_cCommand [32];
static char g_cFileName [FILES][80];
static int g_nFiles = 0;

//-------+---------+---------+---------+---------+---------+---------+-----
// Define Local Prototype :
//-------+---------+---------+---------+---------+---------+---------+-----
static void arginit (int argc, char *argv []);
static void usage (int nUsage);
static int ConvUnitString (int nData, char *pUint, int nLength);

//-------+---------+---------+---------+---------+---------+---------+-----
// Main function :
//-------+---------+---------+---------+---------+---------+---------+-----
// Function List >>> main :
//               >>> arginit :
//               >>> usage :
//               >>> ConvUnitString :

///////////////////////////////////////////////////////////////////////////
//>>> main :
///////////////////////////////////////////////////////////////////////////
int main (int argc, char *argv [])
{
  FILE *fp;
  char cUnit [32];
  int i, nDevice;
  int nTimes, nStereo, nChannel, nSmpPerSec, nBitPerSmp, nDataSize;

  arginit (argc, argv);
  if (!g_nFiles)
  {
    usage (TRUE);
    exit (1);
  }
  usage (FALSE);

  if ((nDevice = wgmOpenDevice_WaveDSP ()) < 0)
    exit (1);

  for (i=0; i<g_nFiles; i++)
  {
    fp = wgmOpenFile_WaveDSP (g_cFileName [i], &nTimes, 
      &nStereo, &nChannel, &nSmpPerSec, &nBitPerSmp, &nDataSize);

    if (fp == NULL)
      continue;
    ConvUnitString (nDataSize, cUnit, 32);
    printf ("--------------------------------\n");
    printf ("File name    : %s\n", g_cFileName [i]);
    printf ("Sound        : %s\n", (nStereo==0? "Mono": "Stereo"));
    printf ("Channels     : %d\n", nChannel);
    printf ("Sampling freq: %d Hz\n", nSmpPerSec);
    printf ("Bits         : %d bits\n", nBitPerSmp);
    printf ("Data Size    : %s Bytes\n", cUnit);
    printf ("Total Times  : %d'%02d\"%02d\n\n", 
      (nTimes/100)/60, (nTimes/100)%60, nTimes%100);

    wgmPlay_WaveDSP (fp, nTimes, 
      nStereo, nChannel, nSmpPerSec, nBitPerSmp, nDataSize);

    fclose (fp);
  }

  wgmCloseDevice_WaveDSP ();

  exit (0);
}

///////////////////////////////////////////////////////////////////////////
//>>> arginit :
///////////////////////////////////////////////////////////////////////////
static void arginit (int argc, char *argv [])
{
  char *pCmd;
  int i;

  if ((pCmd = (char *) strrchr (argv [0], '/')) != NULL)
    pCmd++;
  else
    pCmd = argv [0];
  strcpy (g_cCommand, pCmd);

  for (i=1; i<argc; i++)
  {
    if ((strcmp (argv [i], "-help") == 0)
      || (strcmp (argv [i], "-h") == 0))
    {
      usage (TRUE);
      exit (0);
    }else{
      if (g_nFiles<FILES)
      {
        strcpy (g_cFileName [g_nFiles], argv [i]);
        g_nFiles++;
      }else{
        fprintf (stderr, "Warring: Too many file. Less than %d files.\n", 
          FILES);
        return;
      }
    }
  }
}

///////////////////////////////////////////////////////////////////////////
//>>> usage :
///////////////////////////////////////////////////////////////////////////
static void usage (int nUsage)
{
  fprintf (stderr, ">>> " APPNAME " <<<\n");
  fprintf (stderr, "- " APPVERSION " " APPDATE " -\n");
  fprintf (stderr, "- Copyright (C) " APPPRODUCT " -\n");
  fprintf (stderr, "\n");
  fprintf (stderr, " Wingman Linear PCM Wave Player " 
                   "(Command line version) ... \n");
  fprintf (stderr, "\n");
  if (nUsage == FALSE)
    return;
  fprintf (stderr, " Usage: %s [-help] WaveFiles\n", g_cCommand);
  fprintf (stderr, " -help(or -h) ... This message\n");
  fprintf (stderr, "  WaveFiles   ... Linear PCM wave files name\n\n");

}

///////////////////////////////////////////////////////////////////////////
//>>> ConvUnitString :
///////////////////////////////////////////////////////////////////////////
static int ConvUnitString (int nData, char *pUnit, int nLength)
{
  char cUnit [32];

  memset (pUnit, 0, nLength);

  if (nData<1000)
    sprintf (cUnit, "%d", nData);
  else if (nData<1000000) // ex 1,000
    sprintf (cUnit, "%d,%03d", nData/1000, nData%1000);
  else          // ex 1,000,000
    sprintf (cUnit, "%d,%03d,%03d", 
      nData/1000000, (nData/1000)%1000, nData%1000);

  if (strlen (cUnit)<=nLength)
    strcpy (pUnit, cUnit);
  else
    return FALSE;

  return (strlen (cUnit));
}

